@@ -50,10 +50,10 @@ class SmartBin(gst.Pipeline):
         self.height = height
         self.name = name
         self.displayname = displayname
-        
+
         self.vtee = None
         self.atee = None
-        
+
         self.set_name(name)
         # Until  basetransform issues are fixed, we use an identity instead
         # of a tee
@@ -72,6 +72,7 @@ class SmartBin(gst.Pipeline):
         self.encthread = None
         self.tmpasink = None
         self.tmpvsink = None
+        self.recording = False
 
     def _addSource(self):
         """ add the source to self """
@@ -86,7 +87,7 @@ class SmartBin(gst.Pipeline):
         Set the audio sink thread.
         Returns False if there was a problem.
         """
-        self.debug("asinkthread : %s" % asinkthread)
+        self.debug("asinkthread : %r" % asinkthread)
         res, state, pending = self.get_state(0)
         if state == gst.STATE_PLAYING:
             self.warning("is in PAUSED or higher : %s" % state)
@@ -106,7 +107,7 @@ class SmartBin(gst.Pipeline):
         Set the video sink thread.
         Returns False if there was a problem.
         """
-        self.debug("vsinkthread : %s" % vsinkthread)
+        self.debug("vsinkthread : %r" % vsinkthread)
         res , state , pending = self.get_state(0)
         if state == gst.STATE_PLAYING:
             self.warning("is in PAUSED or higher : %s" % state)
@@ -129,7 +130,7 @@ class SmartBin(gst.Pipeline):
         Remove the audio sink thread.
         Returns False if there was a problem.
         """
-        self.debug("asinkthread : %s" % self.asinkthread)
+        self.debug("asinkthread : %r" % self.asinkthread)
         result, state, pending = self.get_state(0)
         if state in [gst.STATE_PAUSED, gst.STATE_PLAYING]:
             self.warning("is in PAUSED, not removing audiosink")
@@ -140,6 +141,7 @@ class SmartBin(gst.Pipeline):
         self.asinkthread.get_pad("sink").get_peer().unlink(self.asinkthread.get_pad("sink"))
         self.remove(self.asinkthread)
         self.asinkthread = None
+        self.log("asinkthread removed succesfully")
         return True
 
     def removeVideoSinkThread(self):
@@ -147,7 +149,7 @@ class SmartBin(gst.Pipeline):
         Remove the videos sink thread.
         Returns False if there was a problem.
         """
-        self.debug("vsinkthread : %s" % self.vsinkthread)
+        self.debug("vsinkthread : %r" % self.vsinkthread)
         result, state, pending = self.get_state(0)
         if state in [gst.STATE_PAUSED, gst.STATE_PLAYING]:
             self.warning("is in PAUSED or higher : %s" % state)
@@ -158,6 +160,7 @@ class SmartBin(gst.Pipeline):
         self.vsinkthread.get_pad("sink").get_peer().unlink(self.vsinkthread.get_pad("sink"))
         self.remove(self.vsinkthread)
         self.vsinkthread = None
+        self.log("vsinkthread removed succesfully")
         return True
 
     def getRealVideoSink(self):
@@ -175,6 +178,10 @@ class SmartBin(gst.Pipeline):
             self.warning("Couldn't switch to READY !")
             return False
 
+        if self.recording:
+            self.error("This bin is already in in recording mode !")
+            return
+
         # temporarily remove the audiosinkthread
         self.debug("disconnecting audio sink thread")
         self.tmpasink = self.asinkthread
@@ -197,13 +204,13 @@ class SmartBin(gst.Pipeline):
 
         # set sync=false on the videosink
         #self.getRealVideoSink().set_property("sync", False)
-        
+
         self.debug("linking vtee to ecnthread:vsink")
         try:
             self.vtee.get_pad("src").link(self.encthread.get_pad("vsink"))
         except:
             return False
-        
+
         self.debug("linking atee to encthread:asink")
         try:
             self.atee.get_pad("src").link(self.encthread.get_pad("asink"))
@@ -215,12 +222,18 @@ class SmartBin(gst.Pipeline):
         self.debug("now in PLAYING, set_state() returned %r" % changeret)
         if changeret == gst.STATE_CHANGE_FAILURE:
             return False
+
+        self.recording = True
         return True
 
     def stopRecording(self):
         """ stop the recording, removing the encoding thread """
+        if self.recording == False:
+            self.error("This bin is not in recording mode !")
+            return False
+
         self.set_state(gst.STATE_PAUSED)
-        
+
         if self.encthread:
             apad = self.encthread.get_pad("vsink")
             apad.get_peer().unlink(apad)
@@ -237,6 +250,9 @@ class SmartBin(gst.Pipeline):
 
         self.getRealVideoSink().set_property("sync", True)
 
+        self.recording = False
+        return True
+
     def getSettings(self):
         """ Return the ExportSettings for the bin """
         return None
@@ -258,13 +274,13 @@ class SmartBin(gst.Pipeline):
         # TODO : verify if encoders take video/x-raw-yuv and audio/x-raw-int
         # TODO : use video/audio settings !
         # TODO : Check if we really do both audio and video !
-        
+
         if not settings:
             setting = self.getSettings()
             if not settings:
                 self.error("No settings available to create the Encoding Thread")
                 return None
-        
+
         thread = gst.Bin("encthread")
 
         ##
@@ -282,7 +298,7 @@ class SmartBin(gst.Pipeline):
         ##
         ## Audio part
         ##
-            
+
         ainq = gst.element_factory_make("queue", "ainq")
         aident = gst.element_factory_make("identity", "aident")
         aident.props.single_segment = True
@@ -319,7 +335,7 @@ class SmartBin(gst.Pipeline):
         ##
         ## Video part
         ##
-            
+
         vinq = gst.element_factory_make("queue", "vinq")
         vident = gst.element_factory_make("identity", "vident")
         vident.props.single_segment = True
@@ -410,7 +426,7 @@ class SmartFileBin(SmartBin):
             pad.unlink(self.vtee.get_pad("sink"))
 
     def getSettings(self):
-        return self.project.getSettings()
+        return self.factory.getExportSettings()
 
     def do_destroy(self):
         self.info("destroyed")
@@ -425,9 +441,9 @@ class SmartTimelineBin(SmartBin):
     def __init__(self, project):
         gst.log("new SmartTimelineBin for project %s" % project)
         self.project = project
-        
+
         settings = project.getSettings()
-        self.log("source is %s" % project.timeline.timeline)
+        self.log("source is %r" % project.timeline.timeline)
         self.source = project.timeline.timeline
         self.project.connect("settings-changed", self._settingsChangedCb)
         project.timeline.videocomp.connect("start-duration-changed", self._startDurationChangedCb)
@@ -470,6 +486,8 @@ class SmartTimelineBin(SmartBin):
         self.info("smart timeline bin: start duration changed %d %d" %( start, duration ))
         self.length = duration
 
+    def getSettings(self):
+        return self.project.getSettings()
 
 class SmartDefaultBin(SmartBin):
     """
@@ -495,4 +513,3 @@ class SmartDefaultBin(SmartBin):
         self.videotestsrc.get_pad("src").link(self.vtee.get_pad("sink"))
         self.silence.get_pad("src").link(self.atee.get_pad("sink"))
         self.debug("finished connecting sources")
-
